==> jc-1.4.0.tar.gz: javax/print/event/PrintJobEvent.h <==
// public class javax.print.event.PrintJobEvent

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 4c95768fb6372ef3 javax_print_event_PrintEvent
// @dep_class 76d3e03d93851506 javax_print_event_PrintJobEvent

// header file dependencies
// @dep_header javax_print_event_PrintEvent

#include "javax/print/event/PrintEvent.h"

#ifndef _JC_javax_print_event_PrintJobEvent_H_
#define _JC_javax_print_event_PrintJobEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_print_DocPrintJob$object;

// Typedefs
typedef struct _jc_javax_print_event_PrintJobEvent$sub_refs	_jc_javax_print_event_PrintJobEvent$sub_refs;
typedef struct _jc_javax_print_event_PrintJobEvent$sub_nonrefs	_jc_javax_print_event_PrintJobEvent$sub_nonrefs;
typedef struct _jc_javax_print_event_PrintJobEvent$refs	_jc_javax_print_event_PrintJobEvent$refs;
typedef struct _jc_javax_print_event_PrintJobEvent$nonrefs	_jc_javax_print_event_PrintJobEvent$nonrefs;
typedef struct _jc_javax_print_event_PrintJobEvent$object	_jc_javax_print_event_PrintJobEvent$object;

typedef struct _jc_javax_print_event_PrintJobEvent$fields_struct	_jc_javax_print_event_PrintJobEvent$fields_struct;
typedef const struct _jc_javax_print_event_PrintJobEvent$vmethods	_jc_javax_print_event_PrintJobEvent$vmethods;
typedef const struct _jc_javax_print_event_PrintJobEvent$vtable	_jc_javax_print_event_PrintJobEvent$vtable;
typedef const struct _jc_javax_print_event_PrintJobEvent$vtype	_jc_javax_print_event_PrintJobEvent$vtype;

// Class fields structure
struct _jc_javax_print_event_PrintJobEvent$fields_struct {
	jlong	serialVersionUID;
	jint	DATA__5fTRANSFER__5fCOMPLETE;
	jint	JOB__5fCANCELED;
	jint	JOB__5fCOMPLETE;
	jint	JOB__5fFAILED;
	jint	NO__5fMORE__5fEVENTS;
	jint	REQUIRES__5fATTENTION;
};
extern _jc_javax_print_event_PrintJobEvent$fields_struct _jc_javax_print_event_PrintJobEvent$class_fields;

// Constructors
extern void _jc_javax_print_event_PrintJobEvent$method$_init$b70c3aac2ce6fe08(_jc_env *, struct _jc_javax_print_event_PrintJobEvent$object *, struct _jc_object *, jint);

// Virtual methods
extern jint _jc_javax_print_event_PrintJobEvent$method$getPrintEventType$787807d1a2c335d1(_jc_env *, struct _jc_javax_print_event_PrintJobEvent$object *);
extern struct _jc_object *_jc_javax_print_event_PrintJobEvent$method$getPrintJob$f4a934baad9b84c8(_jc_env *, struct _jc_javax_print_event_PrintJobEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_event_PrintJobEvent$method_info$getPrintEventType$787807d1a2c335d1;
extern _jc_method _jc_javax_print_event_PrintJobEvent$method_info$getPrintJob$f4a934baad9b84c8;

// Virtual methods structure
struct _jc_javax_print_event_PrintJobEvent$vmethods {
	jint	(*getPrintEventType$787807d1a2c335d1)(_jc_env *, struct _jc_javax_print_event_PrintJobEvent$object *);
	struct _jc_object	*(*getPrintJob$f4a934baad9b84c8)(_jc_env *, struct _jc_javax_print_event_PrintJobEvent$object *);
};

// Vtable
struct _jc_javax_print_event_PrintJobEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_print_event_PrintEvent$vmethods	javax_print_event_PrintEvent;
	_jc_javax_print_event_PrintJobEvent$vmethods	javax_print_event_PrintJobEvent;
};

// Vtype
struct _jc_javax_print_event_PrintJobEvent$vtype {
	_jc_type			type;
	_jc_javax_print_event_PrintJobEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_event_PrintJobEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_event_PrintJobEvent$refs {
    _jc_javax_print_event_PrintJobEvent$sub_refs	javax_print_event_PrintJobEvent;
    _jc_javax_print_event_PrintEvent$sub_refs	javax_print_event_PrintEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_event_PrintJobEvent$sub_nonrefs {
	jint	reason;
};

// Non-reference instance fields (object)
struct _jc_javax_print_event_PrintJobEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_print_event_PrintEvent$sub_nonrefs	javax_print_event_PrintEvent;
    _jc_javax_print_event_PrintJobEvent$sub_nonrefs	javax_print_event_PrintJobEvent;
};

// Object instance structure
struct _jc_javax_print_event_PrintJobEvent$object {
	_jc_javax_print_event_PrintJobEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_event_PrintJobEvent$vtype	*vtype;
	_jc_javax_print_event_PrintJobEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_event_PrintJobEvent$vtype _jc_javax_print_event_PrintJobEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_event_PrintJobEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_event_PrintJobEvent$class_object;

#endif	/* _JC_javax_print_event_PrintJobEvent_H_ */

==> jc-1.4.6.tar.gz: javax/print/event/PrintJobEvent.h <==
// public class javax.print.event.PrintJobEvent

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 4c95768fb6372ef3 javax_print_event_PrintEvent
// @dep_class 76d3e03d93851506 javax_print_event_PrintJobEvent

// header file dependencies
// @dep_header javax_print_event_PrintEvent

#include "javax/print/event/PrintEvent.h"

#ifndef _JC_javax_print_event_PrintJobEvent_H_
#define _JC_javax_print_event_PrintJobEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_print_DocPrintJob$object;

// Typedefs
typedef struct _jc_javax_print_event_PrintJobEvent$sub_refs	_jc_javax_print_event_PrintJobEvent$sub_refs;
typedef struct _jc_javax_print_event_PrintJobEvent$sub_nonrefs	_jc_javax_print_event_PrintJobEvent$sub_nonrefs;
typedef struct _jc_javax_print_event_PrintJobEvent$refs	_jc_javax_print_event_PrintJobEvent$refs;
typedef struct _jc_javax_print_event_PrintJobEvent$nonrefs	_jc_javax_print_event_PrintJobEvent$nonrefs;
typedef struct _jc_javax_print_event_PrintJobEvent$object	_jc_javax_print_event_PrintJobEvent$object;

typedef struct _jc_javax_print_event_PrintJobEvent$fields_struct	_jc_javax_print_event_PrintJobEvent$fields_struct;
typedef const struct _jc_javax_print_event_PrintJobEvent$vmethods	_jc_javax_print_event_PrintJobEvent$vmethods;
typedef const struct _jc_javax_print_event_PrintJobEvent$vtable	_jc_javax_print_event_PrintJobEvent$vtable;
typedef const struct _jc_javax_print_event_PrintJobEvent$vtype	_jc_javax_print_event_PrintJobEvent$vtype;

// Class fields structure
struct _jc_javax_print_event_PrintJobEvent$fields_struct {
	jlong	serialVersionUID;
	jint	DATA__5fTRANSFER__5fCOMPLETE;
	jint	JOB__5fCANCELED;
	jint	JOB__5fCOMPLETE;
	jint	JOB__5fFAILED;
	jint	NO__5fMORE__5fEVENTS;
	jint	REQUIRES__5fATTENTION;
};
extern _jc_javax_print_event_PrintJobEvent$fields_struct _jc_javax_print_event_PrintJobEvent$class_fields;

// Constructors
extern void _jc_javax_print_event_PrintJobEvent$method$_init$b70c3aac2ce6fe08(_jc_env *, struct _jc_javax_print_event_PrintJobEvent$object *, struct _jc_object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_javax_print_event_PrintJobEvent$method$getPrintEventType$787807d1a2c335d1(_jc_env *, struct _jc_javax_print_event_PrintJobEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_print_event_PrintJobEvent$method$getPrintJob$f4a934baad9b84c8(_jc_env *, struct _jc_javax_print_event_PrintJobEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_event_PrintJobEvent$method_info$getPrintEventType$787807d1a2c335d1;
extern _jc_method _jc_javax_print_event_PrintJobEvent$method_info$getPrintJob$f4a934baad9b84c8;

// Virtual methods structure
struct _jc_javax_print_event_PrintJobEvent$vmethods {
	jint	(*getPrintEventType$787807d1a2c335d1)(_jc_env *, struct _jc_javax_print_event_PrintJobEvent$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getPrintJob$f4a934baad9b84c8)(_jc_env *, struct _jc_javax_print_event_PrintJobEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_event_PrintJobEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_print_event_PrintEvent$vmethods	javax_print_event_PrintEvent;
	_jc_javax_print_event_PrintJobEvent$vmethods	javax_print_event_PrintJobEvent;
};

// Vtype
struct _jc_javax_print_event_PrintJobEvent$vtype {
	_jc_type			type;
	_jc_javax_print_event_PrintJobEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_event_PrintJobEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_event_PrintJobEvent$refs {
    _jc_javax_print_event_PrintJobEvent$sub_refs	javax_print_event_PrintJobEvent;
    _jc_javax_print_event_PrintEvent$sub_refs	javax_print_event_PrintEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_event_PrintJobEvent$sub_nonrefs {
	jint	reason;
};

// Non-reference instance fields (object)
struct _jc_javax_print_event_PrintJobEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_print_event_PrintEvent$sub_nonrefs	javax_print_event_PrintEvent;
    _jc_javax_print_event_PrintJobEvent$sub_nonrefs	javax_print_event_PrintJobEvent;
};

// Object instance structure
struct _jc_javax_print_event_PrintJobEvent$object {
	_jc_javax_print_event_PrintJobEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_event_PrintJobEvent$vtype	*vtype;
	_jc_javax_print_event_PrintJobEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_event_PrintJobEvent$vtype _jc_javax_print_event_PrintJobEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_event_PrintJobEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_event_PrintJobEvent$class_object;

#endif	/* _JC_javax_print_event_PrintJobEvent_H_ */
